@@ -33,20 +33,19 @@
 class Calc : public Lum::Component
 {
 private:
-  Lum::Model::ActionRef    calculate;
-  Lum::Model::ListTableRef history;
-  Lum::Model::StringRef    calcInput;
-  Lum::TextEditCombo       *comboInput;
-  Lum::Model::StringRef    calcResult;
+  Lum::Model::ActionRef      calculate;
+  Lum::Model::StringTableRef history;
+  Lum::Model::StringRef      calcInput;
+  Lum::TextEditCombo         *comboInput;
+  Lum::Model::StringRef      calcResult;
 
-  Parser                   parser;
+  Parser                     parser;
 
 private:
   void Calculate();
 
 public:
   Calc();
-  ~Calc();
 
   void CalcSize();
 
