@@ -380,8 +380,11 @@ void Parser::AddFunction(const std::string& name, MathFunct function, TokenType
   Digit  = "0".."9"
   Number = @{Digit@} ["." Digit @{Digit@}] ["E" [("+"|"-")] Digit @{Digit@}]
 */
-Parser::TokenType Parser::GetToken(const std::string& string, size_t& pos,
-                                   Parser::Data*& data, Parser::ReturnCode& result)
+Parser::TokenType Parser::GetToken(const std::string& string,
+                                   size_t& pos,
+                                   Parser::Data*& data,
+                                   Parser::ReturnCode& result,
+                                   bool localized)
 {
   size_t       state;
   size_t       bufferPos;
@@ -419,7 +422,7 @@ Parser::TokenType Parser::GetToken(const std::string& string, size_t& pos,
       else if (string[pos]>='0' && string[pos]<='9') {
         state=1;
       }
-      else if (string[pos]==decimalPoint) {
+      else if ((localized && string[pos]==decimalPoint) || (!localized && string[pos]=='.')) {
         buffer.append(1,string[pos]);
         pos++;
         state=2;
@@ -478,7 +481,7 @@ Parser::TokenType Parser::GetToken(const std::string& string, size_t& pos,
        buffer.append(1,string[pos]);
        pos++;
       }
-      if (string[pos]==decimalPoint) {
+      if ((localized && string[pos]==decimalPoint) || (!localized && string[pos]=='.')) {
         buffer.append(1,string[pos]);
         pos++;
         state=2;
@@ -521,7 +524,7 @@ Parser::TokenType Parser::GetToken(const std::string& string, size_t& pos,
           return tokenError;
         }
       }
-      else if (string[pos]==decimalPoint) {
+      else if ((localized && string[pos]==decimalPoint) || (!localized && string[pos]=='.')) {
         result=NODIGIT;
         return tokenError;
       }
@@ -542,29 +545,30 @@ void Parser::ParseFactor(const std::string& string,
                          Data*& data,
                          Parser::ReturnCode& result,
                          Expression *expression,
-                         TokenType& token)
+                         TokenType& token,
+                         bool localized)
 {
   Data *oldFakt;
 
   switch (token) {
   case NUMBER:
     expression->AddPushVar(dynamic_cast<Variable*>(data));
-    token=GetToken(string,pos,data,result);
+    token=GetToken(string,pos,data,result,localized);
     break;
   case LBRAC:
-    token=GetToken(string,pos,data,result);
+    token=GetToken(string,pos,data,result,localized);
     if (token==tokenError) {
       return;
     }
 
-    ParseExpression(string,pos,data,result,expression,token);
+    ParseExpression(string,pos,data,result,expression,token,localized);
 
     if (result!=OK) {
       return;
     }
 
     if (token==RBRAC) {
-      token=GetToken(string,pos,data,result);
+      token=GetToken(string,pos,data,result,localized);
     }
     else {
       result=NORBRAC;
@@ -573,12 +577,12 @@ void Parser::ParseFactor(const std::string& string,
   case OP4:
     oldFakt=data;
 
-    token=GetToken(string,pos,data,result);
+    token=GetToken(string,pos,data,result,localized);
     if (token==tokenError) {
       return;
     }
 
-    ParseFactor(string,pos,data,result,expression,token);
+    ParseFactor(string,pos,data,result,expression,token,localized);
 
     if (result!=OK) {
       return;
@@ -603,11 +607,12 @@ void Parser::ParseBigTerm(const std::string& string,
                           Data*& data,
                           Parser::ReturnCode& result,
                           Expression *expression,
-                          TokenType& token)
+                          TokenType& token,
+                          bool localized)
 {
   Data *oldBig;
 
-  ParseFactor(string,pos,data,result,expression,token);
+  ParseFactor(string,pos,data,result,expression,token,localized);
 
   if (result!=OK) {
     return;
@@ -616,12 +621,12 @@ void Parser::ParseBigTerm(const std::string& string,
   while (token==OP3) {
     oldBig=data;
 
-    token=GetToken(string,pos,data,result);
+    token=GetToken(string,pos,data,result,localized);
     if (token==tokenError) {
       return;
     }
 
-    ParseBigTerm(string,pos,data,result,expression,token);
+    ParseBigTerm(string,pos,data,result,expression,token,localized);
 
     if (result!=OK) {
       return;
@@ -636,12 +641,13 @@ void Parser::ParseTerm(const std::string& string,
                        Data*& data,
                        Parser::ReturnCode& result,
                        Expression *expression,
-                       TokenType& token)
+                       TokenType& token,
+                       bool localized)
 {
   TokenType old;
   Data      *oldTerm;
 
-  ParseBigTerm(string,pos,data,result,expression,token);
+  ParseBigTerm(string,pos,data,result,expression,token,localized);
 
   if (result!=OK) {
     return;
@@ -651,13 +657,13 @@ void Parser::ParseTerm(const std::string& string,
     old=token;
     oldTerm=data;
     if (token==OP2) {
-      token=GetToken(string,pos,data,result);
+      token=GetToken(string,pos,data,result,localized);
       if (token==tokenError) {
         return;
       }
     }
 
-    ParseBigTerm(string,pos,data,result,expression,token);
+    ParseBigTerm(string,pos,data,result,expression,token,localized);
 
     if (result!=OK) {
       return;
@@ -678,7 +684,8 @@ void Parser::ParseExpression(const std::string& string,
                              Data*& data,
                              Parser::ReturnCode& result,
                              Expression *expression,
-                             TokenType& token)
+                             TokenType& token,
+                             bool localized)
 {
   bool   neg;
   size_t old;
@@ -691,13 +698,13 @@ void Parser::ParseExpression(const std::string& string,
     if (token==MINUS) {
       neg=true;
     }
-    token=GetToken(string,pos,data,result);
+    token=GetToken(string,pos,data,result,localized);
     if (token==tokenError) {
       return;
     }
   }
 
-  ParseTerm(string,pos,data,result,expression,token);
+  ParseTerm(string,pos,data,result,expression,token,localized);
 
   if (result!=OK) {
     return;
@@ -711,12 +718,12 @@ void Parser::ParseExpression(const std::string& string,
     old=token;
     oldExp=data;
 
-    token=GetToken(string,pos,data,result);
+    token=GetToken(string,pos,data,result,localized);
     if (token==tokenError) {
       return;
     }
 
-    ParseTerm(string,pos,data,result,expression,token);
+    ParseTerm(string,pos,data,result,expression,token,localized);
 
     if (result!=OK) {
       return;
@@ -757,7 +764,10 @@ void Parser::ParseExpression(const std::string& string,
   - The multiplication operator can be left out. A * will be automatically inserted
     where approximate. But you must write X X and not XX!
 */
-Parser::Expression* Parser::Parse(const std::string& string, Parser::ReturnCode& result, size_t& pos)
+Parser::Expression* Parser::Parse(const std::string& string,
+                                  Parser::ReturnCode& result,
+                                  size_t& pos,
+                                  bool localized)
 {
   Expression *expression;
   TokenType  token;
@@ -768,13 +778,13 @@ Parser::Expression* Parser::Parse(const std::string& string, Parser::ReturnCode&
 
   expression=new Expression();
 
-  token=GetToken(string,pos,data,result);
+  token=GetToken(string,pos,data,result,localized);
 
   if (token==FINISHED) {
     result=NOOP;
   }
   else if (token!=tokenError) {
-    ParseExpression(string,pos,data,result,expression,token);
+    ParseExpression(string,pos,data,result,expression,token,localized);
 
     if (result==OK && token!=FINISHED) {
       if (token==RBRAC) {
